==> qore-1.18.0.tar.bz2: qore-1.18.0/docs/modules/HttpServerUtil/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore HttpServerUtil Module Reference", "index.html", [
    [ "HttpServerUtil Module", "index.html", [
      [ "HttpServerUtil Introduction", "index.html#httpserverutilintro", null ],
      [ "HttpServerUtil Module Release Notes", "index.html#httpserverutil_relnotes", [
        [ "HttpServerUtil 1.1", "index.html#httputil1_1", null ],
        [ "HttpServerUtil 1.0.12", "index.html#httputil1_0_12", null ],
        [ "HttpServerUtil 1.0", "index.html#httputil1_0", null ],
        [ "HttpServerUtil 0.9.11", "index.html#httputil0911", null ],
        [ "HttpServerUtil 0.9.5", "index.html#httputil095", null ],
        [ "HttpServerUtil 0.9.4", "index.html#httputil094", null ],
        [ "HttpServerUtil 0.3.12.1", "index.html#httputil03121", null ],
        [ "HttpServerUtil 0.3.12", "index.html#httputil0312", null ],
        [ "HttpServerUtil 0.3.11.2", "index.html#httputil03112", null ],
        [ "HttpServerUtil 0.3.11.1", "index.html#httputil03111", null ],
        [ "HttpServerUtil 0.3.11", "index.html#httputil0311", null ]
      ] ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__compression__constants.html#gacba7ff553151bfe51acca63193990a0c",
"group__digest__functions.html#ga31657accc4ffcdf966506bb07bc9a5f5",
"group__filesystem__functions.html#gaf04a8a04f9130664f938cf7dc10dbaed",
"group__misc__functions.html#ga0160c0c4cbe7180d70048577e4e40bcc",
"group__parse__options.html#ga889aa80f8ab33266c165478b5fe3c279",
"group__system__and__build__constants.html#gab870ef28f525648a43a31c859a2a6d06",
"namespace_http_server.html#a5ae35b20fd8a8b2d28f9ce4120defee9"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-1.18.1.tar.bz2: qore-1.18.1/docs/modules/HttpServerUtil/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore HttpServerUtil Module Reference", "index.html", [
    [ "HttpServerUtil Module", "index.html", "index" ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__compression__constants.html#gacba7ff553151bfe51acca63193990a0c",
"group__digest__functions.html#ga31657accc4ffcdf966506bb07bc9a5f5",
"group__filesystem__functions.html#gaf04a8a04f9130664f938cf7dc10dbaed",
"group__misc__functions.html#ga0160c0c4cbe7180d70048577e4e40bcc",
"group__parse__options.html#ga889aa80f8ab33266c165478b5fe3c279",
"group__system__and__build__constants.html#gab870ef28f525648a43a31c859a2a6d06",
"namespace_http_server.html#a57d9cd3068800181944d706c5e5ff75a"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
